@@ -8,7 +8,7 @@
     https://octoboxy.com/octobase/
 '''
 
-VERSION             = '0.6.4'
+VERSION             = '0.6.5'
 
 
 # Any exceptions we raise should be defined here
@@ -18,7 +18,7 @@ from .              import errors
 from .              import utils
 
 # Fundamental classes from which to build more complex things
-from .fundamentals  import Controller, ControllerMixin, Enum, Registry
+from .fundamentals  import Controller, ControllerMixin, ControllerNamespace, Enum, Registry
 registry            = Registry()
 
 # Atomic constants
