@@ -6,6 +6,6 @@ from .enums       import Enum
 
 from .registry    import Registry
 
-from .controllers import Controller, ControllerMixin
+from .controllers import Controller, ControllerMixin, ControllerNamespace
 
 from .testing     import TestCase, TestContext, TestModuleContext, TestRunner
